
1)Command :
    
    pip3 install wolapp
    
  ## if pip not installed and getting error, run the below command and then re-run previous command
   
    sudo apt update
    sudo apt install python3-pip
    

2)Command :

    sudo wolapp -H
    

